# How to contribute to aleat3

Do you want to collaborate with aleat3? You can do it easier since version 0.2.5! Go to the [GitHub repository](http://github.com/diddileija/aleat3/), fork it
and make pull requests to be added to the project! Also, you can contribute with the issue solvings (if there's any open) or open one if you have problems with the package.

Also, if you want, send an email [here](mailto:dr01191115@gmail.com) to join the GitHub project and collaborate directly!

## What contributing means

If you are going to contribute to aleat3, you have to know that this is an open source project, protected by the short 
MIT license. If you are going to join, you'll have to be respectful with the team, and collaborate to make Aleatoryous grow
with enhancements, proposals, etc. If you do, welcome to aleat3!
